pub struct ConversionService { /* private fields */ }Expand description
Service for managing file format conversions.
Implementations
Sourceimpl ConversionService
impl ConversionService
pub fn new( conversion_repo: Arc<ConversionJobRepository>, file_repo: Arc<StoredFileRepository>, ) -> Self
Sourcepub async fn request_conversion(
&self,
source_file_id: Uuid,
target_format: &str,
options: Option<Value>,
) -> ServiceResult<ConversionJob>
pub async fn request_conversion( &self, source_file_id: Uuid, target_format: &str, options: Option<Value>, ) -> ServiceResult<ConversionJob>
Request a format conversion for a file.
Sourcepub async fn mark_started(&self, job_id: Uuid) -> ServiceResult<ConversionJob>
pub async fn mark_started(&self, job_id: Uuid) -> ServiceResult<ConversionJob>
Mark a conversion job as started.
Sourcepub async fn update_progress(
&self,
job_id: Uuid,
progress: i32,
) -> ServiceResult<ConversionJob>
pub async fn update_progress( &self, job_id: Uuid, progress: i32, ) -> ServiceResult<ConversionJob>
Update conversion progress (0-100).
Sourcepub async fn mark_completed(
&self,
job_id: Uuid,
result_file_id: Uuid,
) -> ServiceResult<ConversionJob>
pub async fn mark_completed( &self, job_id: Uuid, result_file_id: Uuid, ) -> ServiceResult<ConversionJob>
Mark a conversion job as completed with the result file.
Sourcepub async fn mark_failed(
&self,
job_id: Uuid,
error_message: &str,
) -> ServiceResult<ConversionJob>
pub async fn mark_failed( &self, job_id: Uuid, error_message: &str, ) -> ServiceResult<ConversionJob>
Mark a conversion job as failed with an error message.