FileComment

Struct FileComment 

pub struct FileComment {
    pub id: Uuid,
    pub file_id: Uuid,
    pub user_id: Uuid,
    pub parent_id: Option<Uuid>,
    pub content: String,
    pub annotation_region: Option<Value>,
    pub mentions: Vec<Uuid>,
    pub resolved: bool,
    pub resolved_by: Option<Uuid>,
    pub resolved_at: Option<DateTime<Utc>>,
    pub metadata: AuditMetadata,
    /* private fields */
}

Fields

id: Uuidfile_id: Uuiduser_id: Uuidparent_id: Option<Uuid>content: Stringannotation_region: Option<Value>mentions: Vec<Uuid>resolved: boolresolved_by: Option<Uuid>resolved_at: Option<DateTime<Utc>>metadata: AuditMetadata

Implementations

Source

impl FileComment

pub fn is_reply(&self) -> bool

Check if this is a reply to another comment

pub fn has_annotations(&self) -> bool

Check if comment has region annotations

pub fn get_replies(&self) -> Vec<FileComment>

Get reply comments (aggregate pattern - replies loaded separately via repository)

pub fn resolve(&mut self, by_user_id: Uuid) -> Result<(), CommentError>

Mark comment as resolved

pub fn unresolve(&mut self) -> Result<(), CommentError>

Mark comment as unresolved

pub fn mention_count(&self) -> i32

Count mentioned users

pub fn check_invariants(&self) -> Result<(), Vec<&'static str>>

Check all business invariants

Source

impl FileComment

pub fn builder() -> FileCommentBuilder

Create a builder for FileComment

pub fn new( file_id: Uuid, user_id: Uuid, content: String, mentions: Vec<Uuid>, resolved: bool, status: CommentStatus, ) -> Self

Create a new FileComment with required fields

pub fn id(&self) -> &Uuid

Get the entity’s unique identifier

pub fn typed_id(&self) -> FileCommentId

Get a strongly-typed ID for this entity

pub fn created_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was created

pub fn updated_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was last updated

pub fn is_deleted(&self) -> bool

Check if this entity is soft deleted

pub fn is_active(&self) -> bool

Check if this entity is active (not deleted)

pub fn deleted_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was deleted

pub fn created_by(&self) -> Option<&Uuid>

Get who created this entity

pub fn updated_by(&self) -> Option<&Uuid>

Get who last updated this entity

pub fn deleted_by(&self) -> Option<&Uuid>

Get who deleted this entity

pub fn status(&self) -> &CommentStatus

Get the current status

pub fn with_parent_id(self, value: Uuid) -> Self

Set the parent_id field (chainable)

pub fn with_annotation_region(self, value: Value) -> Self

Set the annotation_region field (chainable)

pub fn with_resolved_by(self, value: Uuid) -> Self

Set the resolved_by field (chainable)

pub fn with_resolved_at(self, value: DateTime<Utc>) -> Self

Set the resolved_at field (chainable)

pub fn transition_to( &mut self, new_state: FileCommentState, ) -> Result<(), StateMachineError>

Transition to a new state via the status state machine.

Returns Err if the transition is not permitted from the current state. Use this method instead of assigning self.status directly.

pub fn apply_patch(&mut self, fields: HashMap<String, Value>)

Apply partial updates from a map of field name to JSON value