ProcessingJob

Struct ProcessingJob 

pub struct ProcessingJob {
    pub id: Uuid,
    pub file_id: Uuid,
    pub job_type: ProcessingJobType,
    pub priority: i32,
    pub input_data: Option<Value>,
    pub result_data: Option<Value>,
    pub error_message: Option<String>,
    pub started_at: Option<DateTime<Utc>>,
    pub completed_at: Option<DateTime<Utc>>,
    pub retry_count: i32,
    pub max_retries: i32,
    pub metadata: AuditMetadata,
    /* private fields */
}

Fields

id: Uuidfile_id: Uuidjob_type: ProcessingJobTypepriority: i32input_data: Option<Value>result_data: Option<Value>error_message: Option<String>started_at: Option<DateTime<Utc>>completed_at: Option<DateTime<Utc>>retry_count: i32max_retries: i32metadata: AuditMetadata

Implementations

Source

impl ProcessingJob

pub fn builder() -> ProcessingJobBuilder

Create a builder for ProcessingJob

pub fn new( file_id: Uuid, job_type: ProcessingJobType, status: JobStatus, priority: i32, retry_count: i32, max_retries: i32, ) -> Self

Create a new ProcessingJob with required fields

pub fn id(&self) -> &Uuid

Get the entity’s unique identifier

pub fn typed_id(&self) -> ProcessingJobId

Get a strongly-typed ID for this entity

pub fn created_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was created

pub fn updated_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was last updated

pub fn is_deleted(&self) -> bool

Check if this entity is soft deleted

pub fn is_active(&self) -> bool

Check if this entity is active (not deleted)

pub fn deleted_at(&self) -> Option<&DateTime<Utc>>

Get when this entity was deleted

pub fn created_by(&self) -> Option<&Uuid>

Get who created this entity

pub fn updated_by(&self) -> Option<&Uuid>

Get who last updated this entity

pub fn deleted_by(&self) -> Option<&Uuid>

Get who deleted this entity

pub fn status(&self) -> &JobStatus

Get the current status

pub fn with_input_data(self, value: Value) -> Self

Set the input_data field (chainable)

pub fn with_result_data(self, value: Value) -> Self

Set the result_data field (chainable)

pub fn with_error_message(self, value: String) -> Self

Set the error_message field (chainable)

pub fn with_started_at(self, value: DateTime<Utc>) -> Self

Set the started_at field (chainable)

pub fn with_completed_at(self, value: DateTime<Utc>) -> Self

Set the completed_at field (chainable)

pub fn transition_to( &mut self, new_state: ProcessingJobState, ) -> Result<(), StateMachineError>

Transition to a new state via the status state machine.

Returns Err if the transition is not permitted from the current state. Use this method instead of assigning self.status directly.

pub fn apply_patch(&mut self, fields: HashMap<String, Value>)

Apply partial updates from a map of field name to JSON value

pub fn can_retry(&self) -> bool

Check if job can be retried (failed and retries remaining)

pub fn increment_retry(&mut self)

Increment retry count

pub fn mark_started(&mut self) -> Result<(), JobError>

Mark job as started

pub fn mark_completed(&mut self, result: Value) -> Result<(), JobError>

Mark job as completed with result

pub fn mark_failed(&mut self, error: String) -> Result<(), JobError>

Mark job as failed with error

pub fn cancel(&mut self) -> Result<(), JobError>

Cancel the job

pub fn duration(&self) -> Option<Duration>

Get job execution duration (completed_at - started_at if both present)

pub fn check_invariants(&self) -> Result<(), Vec<&'static str>>

Check all business invariants