pub struct FileLock {
pub id: Uuid,
pub file_id: Uuid,
pub user_id: Uuid,
pub locked_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub refreshed_at: Option<DateTime<Utc>>,
pub metadata: AuditMetadata,
/* private fields */
}Fields
id: Uuidfile_id: Uuiduser_id: Uuidlocked_at: DateTime<Utc>expires_at: DateTime<Utc>refreshed_at: Option<DateTime<Utc>>metadata: AuditMetadataImplementations
Sourceimpl FileLock
impl FileLock
Sourcepub fn builder() -> FileLockBuilder
pub fn builder() -> FileLockBuilder
Create a builder for FileLock
Sourcepub fn new(
file_id: Uuid,
user_id: Uuid,
locked_at: DateTime<Utc>,
expires_at: DateTime<Utc>,
status: LockStatus,
) -> Self
pub fn new( file_id: Uuid, user_id: Uuid, locked_at: DateTime<Utc>, expires_at: DateTime<Utc>, status: LockStatus, ) -> Self
Create a new FileLock with required fields
Sourcepub fn typed_id(&self) -> FileLockId
pub fn typed_id(&self) -> FileLockId
Get a strongly-typed ID for this entity
Sourcepub fn created_at(&self) -> Option<&DateTime<Utc>>
pub fn created_at(&self) -> Option<&DateTime<Utc>>
Get when this entity was created
Sourcepub fn updated_at(&self) -> Option<&DateTime<Utc>>
pub fn updated_at(&self) -> Option<&DateTime<Utc>>
Get when this entity was last updated
Sourcepub fn is_deleted(&self) -> bool
pub fn is_deleted(&self) -> bool
Check if this entity is soft deleted
Sourcepub fn deleted_at(&self) -> Option<&DateTime<Utc>>
pub fn deleted_at(&self) -> Option<&DateTime<Utc>>
Get when this entity was deleted
Sourcepub fn created_by(&self) -> Option<&Uuid>
pub fn created_by(&self) -> Option<&Uuid>
Get who created this entity
Sourcepub fn updated_by(&self) -> Option<&Uuid>
pub fn updated_by(&self) -> Option<&Uuid>
Get who last updated this entity
Sourcepub fn deleted_by(&self) -> Option<&Uuid>
pub fn deleted_by(&self) -> Option<&Uuid>
Get who deleted this entity
Sourcepub fn status(&self) -> &LockStatus
pub fn status(&self) -> &LockStatus
Get the current status
Sourcepub fn with_refreshed_at(self, value: DateTime<Utc>) -> Self
pub fn with_refreshed_at(self, value: DateTime<Utc>) -> Self
Set the refreshed_at field (chainable)
Sourcepub fn transition_to(
&mut self,
new_state: FileLockState,
) -> Result<(), StateMachineError>
pub fn transition_to( &mut self, new_state: FileLockState, ) -> Result<(), StateMachineError>
Transition to a new state via the status state machine.
Returns Err if the transition is not permitted from the current state.
Use this method instead of assigning self.status directly.
Sourcepub fn apply_patch(&mut self, fields: HashMap<String, Value>)
pub fn apply_patch(&mut self, fields: HashMap<String, Value>)
Apply partial updates from a map of field name to JSON value
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Check if lock is still valid (active status and not yet expired)
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if lock has expired (expires_at is at or before the current time)
Sourcepub fn is_owned_by(&self, user_id: Uuid) -> bool
pub fn is_owned_by(&self, user_id: Uuid) -> bool
Check if lock belongs to the given user
Sourcepub fn can_refresh(&self) -> bool
pub fn can_refresh(&self) -> bool
Check if lock can be refreshed (must be currently valid)
Sourcepub fn refresh(&mut self, duration: Duration) -> Result<(), LockError>
pub fn refresh(&mut self, duration: Duration) -> Result<(), LockError>
Refresh lock expiry time by extending it by the given duration
Sourcepub fn time_remaining(&self) -> Duration
pub fn time_remaining(&self) -> Duration
Get remaining time until expiry. Returns zero duration if already expired.